<?php 
/**
 *
 *  Provides a comfortable fallback so that theme
 *  builders can utilize twentyten's full blogging 
 *  support without reinventing the wheel.
 *  
 *  Enjoy!
 * 
 * @package Placester
 * @subpackage Placester
 * @since Placester 0.1
 */


function placester_get_route ()
{
    	$template = false;
    	if     ( is_404()            && $template = dirname(__FILE__) . '/../templates/404.php' ) :
    	elseif ( is_search()         && $template = dirname(__FILE__) . '/../templates/search.php' ) :
    	elseif ( is_tax()            && $template = dirname(__FILE__) . '/../templates/tax.php' ) :
    	elseif ( is_front_page()     && $template = dirname(__FILE__) . '/../templates/home.php' ) :
    	elseif ( is_home()           && $template = dirname(__FILE__) . '/../templates/home.php'           ) :
    	elseif ( is_attachment()     && $template = dirname(__FILE__) . '/../templates/attachment.php'     ) :
    		remove_filter('the_content', 'prepend_attachment');
    	elseif ( is_single()         && $template = dirname(__FILE__) . '/../templates/single.php'         ) :
    	elseif ( is_page()           && $template = dirname(__FILE__) . '/../templates/page.php'           ) :
    	elseif ( is_category()       && $template = dirname(__FILE__) . '/../templates/category.php'       ) :
    	elseif ( is_tag()            && $template = dirname(__FILE__) . '/../templates/tag.php'            ) :
    	elseif ( is_author()         && $template = dirname(__FILE__) . '/../templates/author.php'         ) :
    	elseif ( is_date()           && $template = get_date_template()           ) :
    	elseif ( is_archive()        && $template = dirname(__FILE__) . '/../templates/archive.php'        ) :
    	elseif ( is_comments_popup() && $template = dirname(__FILE__) . '/../templates/comments.php' ) :
    	elseif ( is_paged()          && $template = get_paged_template()          ) :
    	else :
    		$template = get_index_template();
    	endif;
    	if ( $template = apply_filters( 'template_include', $template ) )
    		include( $template );
    	return;    
}

function placester_get_template_part ( $slug, $name = null )
{

	$templates = array();
	if ( isset($name) )
		$templates[] = "{$slug}-{$name}.php";

	$templates[] = "{$slug}.php";

	placester_locate_template($templates, true, false);
}



/**
 * Just a wrapper to locate_backbone file for templates 
 *
 * @since 2.7.0
 *
 * @param string|array $template_names Template file(s) to search for, in order.
 * @param bool $load If true the template file will be loaded if it is found.
 * @param bool $require_once Whether to require_once or require. Default true. Has no effect if $load is false.
 * @return string The template filename if one is located.
 */
function placester_locate_view($template_names, $load = false, $require_once = true ) {
    
    	return placester_locate_backbone_file('/../views/', $template_names, $load, $require_once);
}
 
/**
 * Just a wrapper to locate_backbone file for templates 
 *
 * @since 2.7.0
 *
 * @param string|array $template_names Template file(s) to search for, in order.
 * @param bool $load If true the template file will be loaded if it is found.
 * @param bool $require_once Whether to require_once or require. Default true. Has no effect if $load is false.
 * @return string The template filename if one is located.
 */
function placester_locate_template($template_names, $load = false, $require_once = true ) {
    
    	return placester_locate_backbone_file('/../templates/', $template_names, $load, $require_once);
}


/**
 * Retrieve the name of the highest priority template file that exists.
 *
 * Searches in the STYLESHEETPATH before TEMPLATEPATH so that themes which
 * inherit from a parent theme can just overload one file.
 *
 * @since 2.7.0
 *
 * @param string|array $template_names Template file(s) to search for, in order.
 * @param bool $load If true the template file will be loaded if it is found.
 * @param bool $require_once Whether to require_once or require. Default true. Has no effect if $load is false.
 * @return string The template filename if one is located.
 */
function placester_locate_backbone_file($directory, $template_names, $load = false, $require_once = true ) {
	$located = '';
	foreach ( (array) $template_names as $template_name ) {
		if ( !$template_name )
			continue;
		if ( file_exists(dirname(__FILE__) . $directory . $template_name)) {
			$located = dirname(__FILE__) . $directory . $template_name;
			break;
		} 
	}

	if ( $load && '' != $located )
		load_template( $located, $require_once );

	return $located;
}
