<?php 
// Add theme setup code here
// Overwriters placester_setup defined in backbone
function placester_setup() {

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// Post Format support. You can also use the legacy "gallery" or "asides" (note the plural) categories.
	add_theme_support( 'post-formats', array( 'aside', 'gallery' ) );

	// This theme uses post thumbnails
	add_theme_support( 'post-thumbnails' );

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Navigation', 'placester' ),
	) );

	// This theme allows users to set a custom background
	add_custom_background();

	// Your changeable header business starts here
	if ( ! defined( 'HEADER_TEXTCOLOR' ) )
		define( 'HEADER_TEXTCOLOR', '' );

    // Define default header image
    if ( ! defined( 'HEADER_IMAGE' ) ) define( 'HEADER_IMAGE', '%s/images/sample-slide.png' );

    define( 'HEADER_IMAGE_WIDTH', apply_filters( 'allure_header_image_width', 620 ) );
    define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'allure_header_image_height', 323 ) );

	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be 940 pixels wide by 198 pixels tall.
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	set_post_thumbnail_size( HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true );

	// Don't support text inside the header image.
	if ( ! defined( 'NO_HEADER_TEXT' ) )
		define( 'NO_HEADER_TEXT', true );

	add_custom_image_header( '', 'placester_admin_header_style' );
    
}

// ==================================
// = Standard Functions / Utilities =
// ==================================

/**
 *       Switch theme 
 */
include('backbone/functions/enqueue.php');
include("parts/enqueue.php");

// Thats all you need =)
include('backbone/init.php');

/**
 *      switch_theme.php makes the necessary updates to the users pages 
 *      once the theme is activated
 */
require('parts/switch_theme.php');

function placester_footer_nav() {
?>
            <nav class="footer-nav">
                <ul>
                    <li><a href="/">Home</a></li>
                    <li><a href="<?php echo @get_permalink(get_page_by_title('Search')->ID); ?>">Search</a></li>
                    <li><a href="<?php echo @get_permalink(get_page_by_title('Contact')->ID); ?>">Contact</a></li>
                    <li><a href="<?php echo @get_permalink(get_page_by_title('About')->ID); ?>">About us</a></li>
                </ul>
            </nav>
<?php
}
add_action('placester_footer_bar', 'placester_footer_nav');
/**
 *
 * @desc registers a theme activation hook
 * @param string $code : Code of the theme. This can be the base folder of your theme. Eg if your theme is in folder 'mytheme' then code will be 'mytheme'
 * @param callback $function : Function to call when theme gets activated.
 */
function wp_register_theme_activation_hook($code, $function) {
    $optionKey="theme_is_activated_" . $code;
    if(!get_option($optionKey)) {
        call_user_func( $function );
        update_option($optionKey , 1);
    }
}
                        
    /**
     *      Featured Property Method
     */
    function display_featured_listings ($limit)
    {
        try {    
            $featured_listings = placester_property_list(array('is_featured' => TRUE));
        }
        catch (PlaceSterNoApiKeyException $e) {
            return;
        }

            $i = 1;
            $flag = FALSE;
                // print_r($featured_listings);
            foreach ($featured_listings->properties as $listing) {
                if ($i == $limit)
                    $flag = TRUE;
                ?>
                
                <section class="<?php echo !isset($flag) ? 'feat-listing' : 'feat-listing2' ?>">
                    <a href="<?php echo placester_get_property_url($listing->id); ?>" class="feat-title"><?php echo @$listing->location->full_address; ?></a>
                    <section class="feat-details">
                        <section class="feat-thumb-size">
                            <div class="thumbs">
                                <img src="<?php echo isset($listing->images[0]->url) ? $listing->images[0]->url :  get_bloginfo('template_url') . '/backbone/images/null/property2-73-37.png';  ?>" width=120 alt="" />
                            </div>
                            <div class="thumbs-shadow"></div>
                        </section>
                        <section class="feat-txt">
                            <p><?php echo $listing->bedrooms . ' bed, ' . $listing->bathrooms . ' bath for $' . $listing->price . ' available ' . $listing->available_on ?></p>
                            <a href="<?php echo placester_get_property_url($listing->id); ?>" class="learnmore-btn-sml">Learn More</a>
                        </section>
                        <div class="clr"></div>
                    </section>
                </section>       
                <?php
                $i++;
                if ($flag) 
                    break;
            }
    }

    /**
     *      Featured Property Method
     */
    function display_new_listings ($limit)
    {
        try {    
            $new_listings = placester_property_list(array('is_new' => TRUE));
        }
        catch (PlaceSterNoApiKeyException $e) {

            
        }

            $i = 1;
            $flag = FALSE;
                // print_r($featured_listings);
            foreach ($new_listings->properties as $listing) {
                if ($i == $limit)
                    $flag = TRUE;
                ?>
                
                <section class="<?php echo !isset($flag) ? 'feat-listing' : 'feat-listing2' ?>">
                    <a href="<?php echo placester_get_property_url($listing->id); ?>" class="feat-title"><?php echo @$listing->location->full_address; ?></a>
                    <section class="feat-details">
                        <section class="feat-thumb-size">
                            <div class="thumbs">
                                <img src="<?php echo isset($listing->images[0]->url) ? $listing->images[0]->url :  get_bloginfo('template_url') . '/backbone/images/null/property2-73-37.png';  ?>" width=120 height=100 alt="" />
                            </div>
                            <div class="thumbs-shadow"></div>
                        </section>
                        <section class="feat-txt">
                            <p><?php echo $listing->bedrooms . ' bed, ' . $listing->bathrooms . ' bath for $' . $listing->price . ' available ' . $listing->available_on ?></p>
                            <a href="<?php echo placester_get_property_url($listing->id); ?>" class="learnmore-btn-sml">Learn More</a>
                        </section>
                        <div class="clr"></div>
                    </section>
                </section>       
                <?php
                $i++;
                if ($flag) 
                    break;
            }
    }

    /**
     *      A series of simple functions for generating our html 
     *      for city / state / zip lists.  This is custom to our markup
     *      change to your needs.
     */
    function display_cities()
    {
        try {
            $locations = placester_location_list();
            sort($locations->city);
            $selected = TRUE;
            foreach ($locations->city as $city) {
                ?>
                    <option value="<?php echo $city; ?>" <?php //echo $selected ? 'selected="selected"' : ''; ?> ><?php echo $city; ?></option>
                <?php
                $selected = FALSE;
            }
        }
        catch (PlaceSterNoApiKeyException $e) {
        }
    }
    function display_cities_footer($num_results = FALSE)
    {
        try {
            $locations = placester_location_list();
            sort($locations->city);
            $last_flag = FALSE;
            $i = 1;
            foreach ($locations->city as $city) {
                if ($num_results && $i == $num_results) {
                    $last_flag = true;
                }
                ?>
                    <li <?php echo $last_flag ? 'class="no-border"' : '' ?> ><a href="/"><?php echo $city; ?></a></li>
                <?php
                
                if ($last_flag) 
                    break;
                
                $i++;
            }
        }
        catch (PlaceSterNoApiKeyException $e) {
        }
    }
    function display_zips_footer($num_results = FALSE)
    {
        try {
            $locations = placester_location_list();
            sort($locations->zip);
            $last_flag = FALSE;
            $i = 1;
            foreach ($locations->zip as $zip) {
                if ($num_results && $i == $num_results) {
                    $last_flag = true;
                }
                ?>
                    <li <?php echo $last_flag ? 'class="no-border"' : '' ?> ><a href="/"><?php echo $zip; ?></a></li>
                <?php
                
                if ($last_flag)
                    break;

                $i++;
            }
        }
        catch (PlaceSterNoApiKeyException $e) {
        }
    }
    

    
    
    
    
    /**
     *      Form Posting
     *      Handles some of the complicated bits about form generation so things just work.
     */
     function get_form_link () 
     {
         $search_page_id = get_page_by_title('search')->ID;

         global $wp_rewrite;

         if ($wp_rewrite->using_permalinks()) {
             $form->search_url = get_permalink($search_page_id);
             $form->hidden_field = '';             
         } else {
           $form->search_url = "index.php";
           $form->hidden_field = "<input type=hidden name=page_id value=$search_page_id />";
         }
         
         return $form;

     }
     


     /**
      *     For Building the Unstructured list on the search page
      */
      function display_unstructured_list()
      {
          include('parts/unstructured_list.php');
      }
      
      
      /**
       *    When viewing a listing details page, grab the post data and make it available.
       */
       function get_property_details()
       {
           
           global $post;
           $listing = json_decode($post->post_content);
           return $listing;
           
       }
       
       /**
        *   Registers the various sidebars for Allure
        */
        function register_custom_sidebars() 
        {
            // Footer Control For all Pages.
        	register_sidebar( array(
        		'name' => __( 'Allure Footer', 'allure' ),
        		'id' => 'allure-footer-widget-area',
        		'description' => __( 'These widgets will be displayed in the footer', 'allure' ),
        		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
        		'after_widget' => '</li>',
        		'before_title' => '<h3 class="widget-title">',
        		'after_title' => '</h3>',
        	) );
        	// Footer Control For Search
        	register_sidebar( array(
        		'name' => __( 'Allure Search Sidebar', 'allure' ),
        		'id' => 'allure-search-widget-area',
        		'description' => __( 'These widgets will be displayed in the sidebar on the search page', 'allure' ),
        		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
        		'after_widget' => '</li>',
        		'before_title' => '<h3 class="widget-title">',
        		'after_title' => '</h3>',
        	) );
        	
            // Sidebar control for all blog
        	register_sidebar( array(
        		'name' => __( 'Allure Blog Sidebar', 'allure' ),
        		'id' => 'allure-blog-widget-area',
        		'description' => __( 'These widgets will be displayed on the blog and all posts.', 'allure' ),
        		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
        		'after_widget' => '</li>',
        		'before_title' => '<h3 class="widget-title">',
        		'after_title' => '</h3>',
        	) );
        	
            // Sidebar Control For all Property Details.
        	register_sidebar( array(
        		'name' => __( 'Allure Property Details Sidebar', 'allure' ),
        		'id' => 'allure-details-widget-area',
        		'description' => __( 'These widgets will be displayed on all property details pages.', 'allure' ),
        		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
        		'after_widget' => '</li>',
        		'before_title' => '<h3 class="widget-title">',
        		'after_title' => '</h3>',
        	) );
        	
        }
        add_action( 'widgets_init', 'register_custom_sidebars' );
